summaryrefslogtreecommitdiffstats
path: root/src/pinyin.h
diff options
context:
space:
mode:
authorPeng Wu <alexepico@gmail.com>2016-06-28 10:58:13 +0800
committerPeng Wu <alexepico@gmail.com>2016-06-28 10:58:13 +0800
commitb348cbc5a0cc19ac4f601e9d73b6851768331e5d (patch)
treea7b5cbbabb5468ec5d4a36b83b767501535a5952 /src/pinyin.h
parenteedae34d203bc1a07a1d09f7876661649538462a (diff)
downloadlibpinyin-b348cbc5a0cc19ac4f601e9d73b6851768331e5d.tar.gz
libpinyin-b348cbc5a0cc19ac4f601e9d73b6851768331e5d.tar.xz
libpinyin-b348cbc5a0cc19ac4f601e9d73b6851768331e5d.zip
fixes pinyin_get_character_offset function
Diffstat (limited to 'src/pinyin.h')
-rw-r--r--src/pinyin.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/pinyin.h b/src/pinyin.h
index 3400568..c691197 100644
--- a/src/pinyin.h
+++ b/src/pinyin.h
@@ -901,16 +901,16 @@ bool pinyin_get_right_character_offset(pinyin_instance_t * instance,
/**
* pinyin_get_character_offset:
* @instance: the pinyin instance.
* @offset: the lookup offset.
* @length: the character offset.
* @returns: whether the get operation is successful.
*
* Get the character offset from the lookup offset.
*
*/
bool pinyin_get_character_offset(pinyin_instance_t * instance,
- size_t offset,
- size_t * length);
+ size_t cursor,
+ size_t * offset);
#if 0
/**
@@ -901,16 +901,16 @@ bool pinyin_get_right_character_offset(pinyin_instance_t * instance,
* pinyin_get_character_offset:
* @instance: the pinyin instance.
- * @offset: the lookup offset.
- * @length: the character offset.
+ * @cursor: the lookup cursor.
+ * @offset: the character offset.
* @returns: whether the get operation is successful.
*
@@ -901,16 +901,16 @@ bool pinyin_get_right_character_offset(pinyin_instance_t * instance,
* @returns: whether the get operation is successful.
*
- * Get the character offset from the lookup offset.
+ * Get the character offset from the lookup cursor.
*
*/